Module: SelectiveInspect::InstanceMethods
- Defined in:
- lib/selective_inspect.rb
Instance Method Summary collapse
-
#inspect(*whitelist) ⇒ Object
Public: Inspects this object in a customizable way.
Instance Method Details
#inspect(*whitelist) ⇒ Object
Public: Inspects this object in a customizable way.
whitelist - (optional) The names of the instance variables to be inspected
Examples
Player.new(id: 1, name: 'John', health: 100, ip_address: '192.168.1.133')
# =>
Returns the String that describes this object and its internals.
33 34 35 |
# File 'lib/selective_inspect.rb', line 33 def inspect(*whitelist) SelectiveInspect.perform_inspect(self, *whitelist) end |